@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.200000';
+$BalanceOfPower::Commands::VERSION = '0.300000';
 use v5.10;
 use Moo;
 use IO::Prompter;
@@ -79,11 +79,7 @@ sub set_player
 {
     my $self = shift;
     my $player = shift;
-    my $log_name = $player . ".log";
-    $log_name =~ s/ /_/g;
-    my $pl = BalanceOfPower::Player->new(name => $player, money => START_PLAYER_MONEY, log_name => $log_name);
-    $pl->delete_log();
-    $self->world->add_player($pl);
+    $self->world->create_player($player);
     $self->active_player($player);
 }
 
@@ -171,6 +167,18 @@ sub verify_nation
     return @good_nation > 0;
 }
 
+sub set_executive
+{
+    my $self = shift;
+    my $controlled_nation = shift;
+
+    my $exec = BalanceOfPower::Executive->new;
+    $exec->init($self->world);
+    $exec->actor($controlled_nation);
+    $self->executive($exec);
+    return $exec;
+}
+
 sub turn_command
 {
     my $self = shift;
@@ -272,7 +280,39 @@ COMMANDS
     }
     elsif($query eq "alliances")
     {
-        print $self->world->print_allies();
+        print $self->world->print_allies(undef, 'print');
+        $result = { status => 1 };
+    }
+    elsif($query eq "static")
+    {
+        open(my $html, "> report.html");
+        print {$html} "<html><head></head><body>\n";
+        print {$html} $self->world->print_hotspots('html');
+        print {$html} "\n";
+        print {$html} $self->world->print_allies(undef, 'html');
+        print {$html} "\n";
+        print {$html} $self->world->print_influences(undef, 'html');
+        print {$html} "\n";
+        print {$html} $self->world->print_military_supports(undef, 'html');
+        print {$html} "\n";
+        print {$html} $self->world->print_rebel_military_supports(undef, 'html');
+        print {$html} "\n";
+        print {$html} $self->world->print_war_history('html');
+        print {$html} "\n";
+        print {$html} $self->world->print_turn_statistics($self->world->get_prev_year(), undef, 'html');  
+        print {$html} "\n";
+        print {$html} $self->world->print_borders_analysis('Italy', 'html');  
+        print {$html} "\n";
+        print {$html} $self->world->print_near_analysis('Italy', 'html');  
+        print {$html} "\n";
+        print {$html} $self->world->print_diplomacy('Italy', 'html');  
+        print {$html} "\n";
+        print {$html} $self->world->print_formatted_turn_events('1975', undef, 'html');  
+        print {$html} "\n";
+        print {$html} $self->world->print_nation_events('Italy', '1975', undef, 'html');  
+        print {$html} "\n";
+        print {$html} "</body></html>";
+        close($html);
         $result = { status => 1 };
     }
     elsif($query eq "influences")
@@ -516,7 +556,7 @@ COMMANDS
 sub orders
 {
     my $self = shift;
-    if($self->executive->actor)
+    if($self->executive && $self->executive->actor)
     {
         if($self->get_active_player->influence($self->executive->actor) >= INFLUENCE_COST)
         {
@@ -626,13 +666,13 @@ sub stock_commands
     {
         my $input_year = $2;
         $input_year ||= prev_turn($self->world->current_year);
-        my @turns = get_year_turns($input_year); 
-        foreach my $t (@turns)
-        {
-            print $self->world->print_stock_events($self->active_player, $t);
-            my $wait = prompt "... press enter to continue ...\n\n" if($t ne $turns[-1]);
-        }
-        print "\n";
+        #my @turns = get_year_turns($input_year); 
+        #foreach my $t (@turns)
+        #{
+        print $self->world->print_stock_events($self->active_player, $input_year, "My stock events", 3);
+            #    my $wait = prompt "... press enter to continue ...\n\n" if($t ne $turns[-1]);
+            #}
+            #print "\n";
         $result = { status => 2 };
     }
 
@@ -670,10 +710,7 @@ sub control_commands
             my $player = $self->get_active_player();
             if($player->influence($controlled_nation) > 0)
             {
-                my $exec = BalanceOfPower::Executive->new;
-                $exec->init($self->world);
-                $exec->actor($controlled_nation);
-                $self->executive($exec);
+                $self->set_executive($controlled_nation);
                 say $self->world->print_nation_actual_situation($controlled_nation, 1);
                 $result = { status => 1 };
             }
@@ -693,6 +730,14 @@ sub control_commands
         say $self->get_active_player->print_control_orders();
         $result = { status => 1 }
     }
+    elsif($query eq "orders")
+    {
+        if($self->executive)
+        {
+           say $self->executive->print_orders();;
+           $result = { status => 1 };
+        }
+    }
     elsif($query eq 'clearorders')
     {
         if($self->executive)
