@@ -1,9 +1,14 @@
 package BalanceOfPower::Commands::NoArgs;
-$BalanceOfPower::Commands::NoArgs::VERSION = '0.200000';
+$BalanceOfPower::Commands::NoArgs::VERSION = '0.300000';
 use Moo;
 
 extends 'BalanceOfPower::Commands::Plain';
 
+sub has_argument
+{
+    return 0;
+}
+
 sub extract_argument
 {
     my $self = shift;
