@@ -1,11 +1,14 @@
 package BalanceOfPower::Relations::Friendship;
-$BalanceOfPower::Relations::Friendship::VERSION = '0.200000';
+$BalanceOfPower::Relations::Friendship::VERSION = '0.300000';
 use strict;
 use v5.10;
 
 use Moo;
 use BalanceOfPower::Constants ':all';
+use BalanceOfPower::Utils qw( as_html_dangerous );
+
 use Term::ANSIColor;
+use HTML::Entities;
 
 has factor => (
     is => 'rw'
@@ -59,6 +62,37 @@ sub status
         return 'NEUTRAL';
     }
 }
+sub status_html_class
+{
+    my $self = shift;
+    if($self->factor == ALLIANCE_FRIENDSHIP_FACTOR)
+    {
+        return 'rel-alliance';
+    }
+    elsif($self->factor == DOMINION_DIPLOMACY)
+    {
+        return 'rel-influence';
+    }
+    if($self->factor <= HATE_LIMIT)
+    {
+        return 'rel-hate';
+    }
+    elsif($self->factor >= LOVE_LIMIT)
+    {
+        return 'rel-friendship';
+    }
+    else
+    {
+        return 'rel-neutral';
+    }
+}
+
+
+sub colored_status
+{
+    my $self = shift;
+    return $self->status_color . $self->status . color("reset");
+}
 
 sub status_color
 {
@@ -81,10 +115,25 @@ sub status_color
     }
 }
 
+
+sub html
+{
+    my $self = shift;
+    my $from = shift;
+    my $link = encode_entities($self->print($from, 0));
+    if($self->status eq 'HATE')
+    {
+        $link = as_html_dangerous($link);
+    }
+    return $link;
+}
+
 sub print 
 {
     my $self = shift;
     my $from = shift;
+    my $color = shift;
+    $color = 1 if(! defined $color);
     my $second_node;
     my $out;
     if($from)
@@ -103,12 +152,20 @@ sub print
         $from = $self->node1;
         $second_node = $self->node2;
     }
-    $out = $self->status_color . $from . " <--> " . $second_node . " [" . $self->factor . " " . $self->status . "]";
+    $out = $self->status_color if $color;
+    $out .=  $from . " <--> " . $second_node . " [" . $self->factor . " " . $self->status . "]";
     if($self->get_crisis_level > 0)
     {
-        $out .= " " . $self->print_crisis_bar();
+        if($color)
+        {
+            $out .= " " . $self->print_crisis_bar();
+        }
+        else
+        {
+            $out .= " " . $self->print_grey_crisis_bar();
+        }
     }
-    $out .= color("reset");
+    $out .= color("reset") if $color;
     return $out;
 }
 sub print_status
@@ -138,6 +195,11 @@ sub print_crisis
         return "";
     }
 }
+sub html_crisis
+{
+    my $self = shift;
+    return encode_entities($self->print_crisis(0));
+}
 sub print_grey_crisis_bar
 {
     my $self = shift;
@@ -194,7 +256,7 @@ sub cooldown_crisis
 sub is_crisis
 {
     my $self = shift;
-    return $self->crisis_level > 0;
+    return $self->get_crisis_level() > 0;
 }
 sub is_max_crisis
 {
