@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::RelPack;
-$BalanceOfPower::Relations::RelPack::VERSION = '0.200000';
+$BalanceOfPower::Relations::RelPack::VERSION = '0.300000';
 use strict;
 use v5.10;
 
@@ -265,6 +265,20 @@ sub query
     }
     return @out;
 }
+sub output_links
+{
+    my $self = shift;
+    my $n = shift;
+    my $mode = shift || 'print';
+    if($mode eq 'print')
+    {
+        return $self->print_links($n);
+    }
+    elsif($mode eq 'html')
+    {
+        return $self->html_links($n);
+    }
+}
 
 sub print_links
 {
@@ -287,6 +301,27 @@ sub print_links
     }
     return $out;
 }
+sub html_links
+{
+    my $self = shift;
+    my $n = shift;
+    my $out = "";
+    foreach my $b (@{$self->links})
+    {
+        if($n)
+        {
+            if($b->has_node($n))
+            {
+                $out .= $b->html($n) . "<br />";
+            }
+        }
+        else
+        {
+            $out .= $b->html($n) . "<br />";
+        }
+    }
+    return "<p>$out</p>";
+}
 
 #BFS implementation
 sub distance
