@@ -1,7 +1,8 @@
 package BalanceOfPower::Relations::Role::Relation;
-$BalanceOfPower::Relations::Role::Relation::VERSION = '0.200000';
+$BalanceOfPower::Relations::Role::Relation::VERSION = '0.300000';
 use strict;
 use Moo::Role;
+use HTML::Entities;
 
 has node1 => (
     is => 'ro'
@@ -73,6 +74,21 @@ sub start
         return undef;
     }
 }
+sub output
+{
+    my $self = shift;
+    my $mode = shift;
+    if($mode eq 'print')
+    {
+        return $self->print;
+    }
+    elsif($mode eq 'html')
+    {
+        return $self->html;
+    }
+}
+
+
 sub print 
 {
     my $self = shift;
@@ -104,6 +120,11 @@ sub print
         }
     }
 }
+sub html
+{
+    my $self = shift;
+    return encode_entities($self->print);
+}
 sub dump
 {
     my $self = shift;
