@@ -1,11 +1,12 @@
 package BalanceOfPower::Relations::War;
-$BalanceOfPower::Relations::War::VERSION = '0.200000';
+$BalanceOfPower::Relations::War::VERSION = '0.300000';
 use strict;
 use v5.10;
 
 use Moo;
-use BalanceOfPower::Utils qw( from_to_turns );
+use BalanceOfPower::Utils qw( from_to_turns as_html_evidenced );
 use Term::ANSIColor;
+use HTML::Entities;
 
 with 'BalanceOfPower::Relations::Role::Relation';
 with 'BalanceOfPower::Role::Reporter';
@@ -48,48 +49,61 @@ sub bidirectional
 {
     return 0;
 }
-sub print 
+
+sub print
 {
     my $self = shift;
     my $army_node1 = shift;
     my $army_node2 = shift;
+    return $self->output($army_node1, $army_node2, 'print');
+}
+sub html
+{
+    my $self = shift;
+    my $army_node1 = shift;
+    my $army_node2 = shift;
+    return $self->output($army_node1, $army_node2, 'html');
+}
+
+
+
+sub output 
+{
+    my $self = shift;
+    my $army_node1 = shift;
+    my $army_node2 = shift;
+    my $mode = shift;
     my $army_node1_label = $army_node1 ? "[".$army_node1."] " : "";
     my $army_node2_label = $army_node2 ? " [".$army_node2."]" : "";
     my $node1 = $army_node1_label . $self->node1;
     my $node2 = $self->node2 . $army_node2_label;
-    if($self->node1_faction == 0)
+    if($mode eq 'print')
     {
-        $node1 = color("bold") . $node1 . color("reset");
-    }
-    else
-    {
-        $node2 = color("bold") . $node2 . color("reset");
-    }
-    return  $node1 . " -> " . $node2;
-}
-sub print_history
-{
-    my $self = shift;
-    my $out = "";
-    #$out .= "### WAR " .  $self->war_id . "\n";
-    $out .= $self->node1;
-    if($self->attack_leader && $self->attack_leader ne $self->node1)
-    {
-        $out .= " (" . $self->attack_leader . ")";
-    }
-    $out .= " => " . $self->node2 . "\n";
-    $out .= "*** War started in " . $self->start_date . " ***\n";
-    $out .= $self->print_turn_events_notitle("START");
-    for(from_to_turns($self->start_date, $self->end_date))
-    {
-        my $events = $self->print_turn_events_inline_year($_);
-        if($events)
+        if($self->node1_faction == 0)
         {
-            $out .= $events;
+            $node1 = color("bold") . $node1 . color("reset");
         }
+        else
+        {
+            $node2 = color("bold") . $node2 . color("reset");
+        }
+        return  $node1 . " -> " . $node2;
     }
-    $out .= "*** War ended in " . $self->end_date . " ***\n";
-    return $out;
+    elsif($mode eq 'html')
+    {
+        if($self->node1_faction == 0)
+        {
+            $node1 = as_html_evidenced($node1);
+        }
+        else
+        {
+            $node2 = as_html_evidenced($node2);
+        }
+        return  $node1 . " -&gt; " . $node2;
+    }
+        
+    
+    
 }
 sub dump
 {
