@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Broker;
-$BalanceOfPower::Role::Broker::VERSION = '0.200000';
+$BalanceOfPower::Role::Broker::VERSION = '0.300000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -154,14 +154,16 @@ sub execute_stock_orders
         $player->empty_stock_orders();
     }
 }
-
 sub print_stock_events
 {
     my $self = shift;
     my $player = shift;
     my $player_obj = $self->get_player($player);
     my $y = shift;
-    return $player_obj->print_turn_events($y);
+    my $title = shift;
+    my $backlog = shift;
+    my $mode = shift;
+    return $player_obj->print_turn_events($y, $title, $backlog, $mode);
 }
 
 1;
