@@ -1,11 +1,13 @@
 package BalanceOfPower::Role::CrisisManager;
-$BalanceOfPower::Role::CrisisManager::VERSION = '0.200000';
+$BalanceOfPower::Role::CrisisManager::VERSION = '0.300000';
 use strict;
+use v5.10;
 use Moo::Role;
+use Template;
 use Term::ANSIColor;
 
 use BalanceOfPower::Constants ':all';
-use BalanceOfPower::Utils qw(as_title);
+use BalanceOfPower::Printer;
 
 requires 'get_all_crises';
 requires 'get_hates';
@@ -145,21 +147,32 @@ sub print_all_crises
 {
     my $self = shift;
     my $n = shift;
-    my $out;
-    $out .= as_title("CRISES\n===\n");
+    my $level = shift || 0;
+    my $mode = shift || 'print';
+    my @crises;
+    my @war_signal;
     foreach my $b ($self->get_all_crises())
     {
-        if($self->war_exists($b->node1, $b->node2))
+        if(( ($n && $b->involve($n) || ! $n)) &&
+          ( $b->get_crisis_level > $level))
         {
-            $out .= color("red bold") . $b->print_crisis() . color("reset") . "\n";
-        }
-        else
-        {
-            $out .= $b->print_crisis() . "\n";
+            push @crises, $b;
+            if($self->war_exists($b->node1, $b->node2))
+            {
+                push @war_signal, 1;
+            }
+            else
+            {
+                push @war_signal, 0;
+            }
         }
     }
-    return $out;
+    my %nation_codes = reverse %{$self->nation_codes};
+    return BalanceOfPower::Printer::print($mode, $self, 'print_all_crises',
+                                          { crises => \@crises,
+                                            wars => \@war_signal,
+                                            nation_codes => \%nation_codes,
+                                           });
 }
-
 1;
 
