@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Diplomat;
-$BalanceOfPower::Role::Diplomat::VERSION = '0.200000';
+$BalanceOfPower::Role::Diplomat::VERSION = '0.300000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -9,6 +9,7 @@ use BalanceOfPower::Constants ':all';
 use BalanceOfPower::Relations::Friendship;
 use BalanceOfPower::Relations::Treaty;
 use BalanceOfPower::Relations::RelPack;
+use BalanceOfPower::Utils qw( as_main_title as_html_box br);
 
 has diplomatic_relations => (
     is => 'ro',
@@ -22,7 +23,6 @@ has treaties => (
     is => 'ro',
     default => sub { BalanceOfPower::Relations::RelPack->new() },
     handles => { add_treaty => 'add_link',
-                 print_treaties => 'print_links',
                  exists_treaty => 'exists_link',
                  get_treaties_for_nation => 'links_for_node',
                  reset_treaties => 'delete_link_for_node',
@@ -112,7 +112,7 @@ sub diplomacy_exists
     my $r = $self->_diplomacy_exists($n1, $n2);
     if(! defined $r)
     {
-        say "ERROR! $n1, $n2";
+        say "ERROR! No diplomacy between $n1, $n2";
     }
     return $r;
 }
@@ -249,25 +249,19 @@ sub diplomacy_for_node
     }
     return %relations;;
 }
+
 sub print_diplomacy
 {
     my $self = shift;
     my $n = shift;
+    my $mode = shift || "print";
     my $out;
-    my @outnodes;
-    foreach my $f ($self->diplomatic_relations->all())
-    {
-        if($f->has_node($n))
-        {
-            my $real_r = $self->diplomacy_exists($n, $f->destination($n));
-            push @outnodes, $real_r;
-        }
-    }
-    foreach my $rr (sort { $a->factor <=> $b->factor} @outnodes)
-    {
-        $out .= $rr->print($n) . "\n";
-    }
-    return $out;
+    my @outnodes = sort { $a->factor <=> $b->factor} $self->get_diplomatic_relations($n);
+    return BalanceOfPower::Printer::print($mode, $self, 'print_diplomacy', 
+                                   { nation => $n,
+                                     relationships => \@outnodes,
+                                   } );
+
 }
 
 
@@ -315,7 +309,7 @@ sub crisis_exists
     my $rel =  $self->diplomacy_exists($nation1, $nation2);
     if(! $rel)
     {
-        say "ERROR: $nation1 <-> $nation2";
+        say "ERROR: no diplomacy between $nation1, $nation2";
         return undef;
     }
     if($rel->get_crisis_level > 0)
@@ -401,16 +395,31 @@ sub add_alliance
 sub print_allies
 {
     my $self = shift;
+    my $nation = shift;
+    my $mode = shift;
+    return $self->print_treaties($nation, "ALLIANCES", 'alliance', $mode);
+}
+sub print_treaties
+{
+    my $self = shift;
+    my $nation = shift;
+    my $title = shift || "TREATIES";
+    my $treaty = shift || undef;
+    my $mode = shift || 'print';
     my @treaties = $self->treaties->all();
-    my $out = "";
+    my @to_print;
     for(@treaties)
     {
-        if($_->type eq 'alliance')
+        if((($treaty && $_->type eq $treaty) || ! $treaty) &&
+          (($nation && $_->involve($nation)) || ! $nation))  
         {
-            $out .= $_->print . "\n";
+            push @to_print, $_;
         }
     }
-    return $out;
+    return BalanceOfPower::Printer::print($mode, $self, 'print_treaties', 
+                                   { title => $title,
+                                     treaties => \@to_print,
+                                   } );
 }
 
 sub exists_alliance
