@@ -1,10 +1,12 @@
 package BalanceOfPower::Role::GameMaster;
-$BalanceOfPower::Role::GameMaster::VERSION = '0.200000';
+$BalanceOfPower::Role::GameMaster::VERSION = '0.300000';
 use strict;
 use v5.10;
 
 use Moo::Role;
 
+use BalanceOfPower::Player;
+
 use BalanceOfPower::Constants ':all';
 
 has players => (
@@ -26,6 +28,23 @@ sub get_player
         return undef;
     }
 }
+sub create_player
+{
+    my $self = shift;
+    my $username = shift;
+    my $already = $self->get_player($username);
+    return 0 if($already);
+    my $log_name = $username . ".log";
+    $log_name =~ s/ /_/g;
+    my $pl = BalanceOfPower::Player->new(name => $username, money => START_PLAYER_MONEY, log_name => $log_name, log_dir => $self->log_dir, current_year => $self->current_year);
+    $pl->delete_log();
+    $pl->register_event("ENTERING THE GAME");
+    $self->register_event("$username IS ENTERING THE GAME");
+    $self->add_player($pl);
+    return 1;
+}
+
+
 sub add_player
 {
     my $self = shift;
