@@ -1,10 +1,11 @@
 package BalanceOfPower::Role::Historian;
-$BalanceOfPower::Role::Historian::VERSION = '0.200000';
+$BalanceOfPower::Role::Historian::VERSION = '0.300000';
 use v5.10;
 use strict;
 use Moo::Role;
 use Term::ANSIColor;
 use List::Util qw( min max );
+use BalanceOfPower::Printer;
 use Data::Dumper;
 
 use BalanceOfPower::Utils qw( get_year_turns as_title from_to_turns );
@@ -63,14 +64,21 @@ sub print_nation_statistics
     my $nation = shift;
     my $first_turn = shift;
     my $last_turn = shift;
-    my $out = as_title($nation . "\n===\n");
-    
-    $out .= "Year\t" . $self->print_nation_statistics_header() . "\n";
+    my $mode = shift || 'print';
+    my $attributes_names = ["Size", "Prod.", "Wealth", "W/D", "Growth", "Disor.", "Army", "Prog.", "Pstg."];
+    my $attributes = ["production", "wealth", "w/d", "growth", "internal disorder", "army", "progress", "prestige"];
+    my %data = ();
+
     foreach my $t (from_to_turns($first_turn, $last_turn))
     {
-        $out .= $t . "\t" . $self->print_nation_statistics_line($nation, $t) . "\n";
+        my @ndata = $self->get_nation_statistics_line($nation, $t, $attributes);
+        $data{$t} = \@ndata;
     }
-    return $out;
+    return BalanceOfPower::Printer::print($mode, $self, 'print_nation_statistics', 
+                                   { nation => $nation,
+                                     attributes => $attributes_names,
+                                     statistics => \%data,
+                                   } );
 }
 sub print_nation_factor
 {
@@ -167,6 +175,20 @@ sub print_nation_statistics_header
         return "Size\tProd.\tWealth\tW/D\tGrowth\tDisor.\tArmy\tProg.\tPstg.";
     }
 }
+sub get_nation_statistics_line
+{
+    my $self = shift;
+    my $nation = shift;
+    my $y = shift;
+    my $characteristics = shift;
+    my @out = ();
+    push @out, $self->get_nation($nation)->size;
+    for(@{$characteristics})
+    {
+        push @out, $self->get_statistics_value($y, $nation, $_);
+    }
+    return @out;
+}
 sub print_nation_statistics_line
 {
     my $self = shift;
@@ -200,9 +222,10 @@ sub print_formatted_turn_events
 {
     my $self = shift;
     my $y = shift;
+    my $title = shift;
+    my $mode = shift || 'print';
     my $out = "";
-    $out .= as_title("\nEvents:\n");
-    $out .= $self->print_turn_events($y);
+    $out .= $self->print_turn_events($y, $title, 0, $mode);
     return $out;
 }
 
@@ -211,8 +234,10 @@ sub print_nation_events
     my $self = shift;
     my $nation_name = shift;
     my $y = shift;
+    my $title = shift;
+    my $mode = shift || 'print';
     my $nation = $self->get_nation($nation_name);
-    return $nation->print_turn_events($y);
+    return $nation->print_turn_events($y, $title, 0, $mode);
 }
 
 sub print_turn_statistics
@@ -220,27 +245,35 @@ sub print_turn_statistics
     my $self = shift;
     my $y = shift;
     my $order = shift;
+    my $mode = shift || 'print';
     my @nations = @{$self->nation_names};
-    my $out = "";
-    $out .= as_title(sprintf "%-16s %-16s", "Nation" , $self->print_nation_statistics_header() . "\n");
+    my $attributes_names = ["Size", "Prod.", "Wealth", "W/D", "Disor.", "Army", "Prog.", "Pstg."];
+    my $attributes = ["production", "wealth", "w/d", "internal disorder", "army", "progress", "prestige"];
+    my %data = ();
+    my @names;
     if($order)
     {
         my @ordered = $self->order_statistics($y, lc $order);
         for(@ordered)
         {
-            my $n = $_->{nation};
-            $out .= sprintf "%-16s %-16s", $n , $self->print_nation_statistics_line($n, $y) . "\n";
+            push @names, $_->{nation};
         } 
     }
     else
     {
-        for(@nations)
-        {
-            $out .= sprintf "%-16s %-16s", $_ , $self->print_nation_statistics_line($_, $y) . "\n";
-        }
+        @names = @nations;
     }
-    $out .= "\n";
-    return $out;
+    for(@names)
+    {
+        my @ndata = $self->get_nation_statistics_line($_, $y, $attributes);
+        $data{$_} = \@ndata;
+    }
+    return BalanceOfPower::Printer::print($mode, $self, 'print_turn_statistics', 
+                                   { year => $y,
+                                     order => $order,
+                                     attributes => $attributes_names,
+                                     statistics => \%data,
+                                     names => \@names, });
 }
 
 sub print_overall_statistics
