@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Recorder;
-$BalanceOfPower::Role::Recorder::VERSION = '0.200000';
+$BalanceOfPower::Role::Recorder::VERSION = '0.300000';
 use strict;
 use v5.10;
 
@@ -16,7 +16,7 @@ sub dump
     my $self = shift;
     my $io = shift;
     my $indent = shift || "";
-    print {$io} $indent . join(";", $self->name, $self->first_year, $self->current_year) . "\n";
+    print {$io} $indent . join(";", $self->name, $self->first_year, $self->current_year, $self->admin_password) . "\n";
     $self->dump_events($io, " " . $indent);
 }
 sub load
@@ -26,13 +26,14 @@ sub load
     my $world_line = ( split /\n/, $data )[0];
     $world_line =~ s/^\s+//;
     chomp $world_line;
-    my ($name, $first_year, $current_year) =
+    my ($name, $first_year, $current_year, $admin_password) =
         split ";", $world_line;
     $data =~ s/^.*?\n//;
     my $events = $self->load_events($data);
     return BalanceOfPower::World->new(name => $name, 
-                                      first_year => $first_year, current_year => $current_year,
+                                      first_year => $first_year, current_year => $current_year, admin_password => $admin_password,
                                       events => $events);
+                                     
 }
 
 sub load_nations
@@ -73,7 +74,7 @@ sub load_players
     foreach my $l (split "\n", $data)
     {
 
-        if($l !~ /^\s/)
+        if($l !~ /^\s/ && $l !~ /^$/)
         {
             if($player_data)
             {
@@ -189,6 +190,10 @@ sub load_world
             elsif($target eq 'WARS')
             {
                 $world->wars->load_pack("BalanceOfPower::Relations::War", $data);
+                for($world->wars->all())
+                {
+                    $_->log_active(0);
+                }
             }
             elsif($target eq 'MEMORIAL')
             {
