@@ -1,9 +1,10 @@
 package BalanceOfPower::Role::Reporter;
-$BalanceOfPower::Role::Reporter::VERSION = '0.200000';
+$BalanceOfPower::Role::Reporter::VERSION = '0.300000';
 use strict;
 use v5.10;
 use Moo::Role;
-use BalanceOfPower::Utils qw( get_year_turns as_title );
+use BalanceOfPower::Utils qw( prev_turn get_year_turns as_title );
+use BalanceOfPower::Printer;
 
 with "BalanceOfPower::Role::Logger";
 
@@ -40,45 +41,29 @@ sub get_events
 
 
 sub print_turn_events
-{
-    my $self = shift;
-    my $y = shift;
-    return $self->_print_turn_events($y, 1);
-}
-
-sub print_turn_events_notitle
-{
-    my $self = shift;
-    my $y = shift;
-    return $self->_print_turn_events($y, 0);
-}
-
-sub print_turn_events_inline_year
-{
-    my $self = shift;
-    my $y = shift;
-    return $self->_print_turn_events($y, 2);
-}
-
-
-sub _print_turn_events
 {
     my $self = shift;
     my $y = shift;
     my $title = shift;
-    my $out = "";
+    my $backlog = shift || 0;
+    my $mode = shift || 'print';
     my @to_print;
     if(! $y)
     {
         $y = $self->current_year ? $self->current_year : "START";
     }
-    if($y =~ /\d\d\d\d/)
+    if($y =~ /^\d\d\d\d$/)
     {
-        @to_print = get_year_turns($y)
+        @to_print = get_year_turns($y);
     }
-    elsif($y =~ /\d\d\d\d\/\d+/)
+    elsif($y =~ /^\d\d\d\d\/\d+$/)
     {
         @to_print = ($y);
+        for(my $i = 0; $i < $backlog; $i++)
+        {
+            push @to_print, prev_turn($y);
+            $y = prev_turn($y);
+        }
     }
     elsif($y eq 'START')
     {
@@ -88,23 +73,14 @@ sub _print_turn_events
     {
         return "";
     }
-    foreach my $t (@to_print)
-    {
-        $out .= as_title($self->name . " - $t\n") if $title == 1;
-        foreach my $e (@{$self->events->{$t}})
-        {
-            $out .= " ";
-            $out .= $t . ": " if($title == 2);
-            $out .= $e . "\n";
-        }
-    }
-    return $out; 
+    return BalanceOfPower::Printer::print($mode, $self, 'print_turn_events', 
+                                   { title => $title,
+                                     turns => \@to_print,
+                                     events => $self->events } );
 }
-sub dump_events
+sub get_turn_tags
 {
     my $self = shift;
-    my $io = shift;
-    my $indent = shift || "";
     sub sort_start
     {
         return 0 if($a eq $b);
@@ -113,7 +89,18 @@ sub dump_events
         return 1 if($a gt $b);
         return -1 if($b gt $a);
     }
-    foreach my $y (sort sort_start keys %{$self->events})
+    return sort sort_start keys %{$self->events};
+}
+
+
+
+sub dump_events
+{
+    my $self = shift;
+    my $io = shift;
+    my $indent = shift || "";
+  
+    foreach my $y ($self->get_turn_tags())
     {
         print {$io} $indent . "### $y\n";
         foreach my $e (@{$self->events->{$y}})
