@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Ruler;
-$BalanceOfPower::Role::Ruler::VERSION = '0.200000';
+$BalanceOfPower::Role::Ruler::VERSION = '0.300000';
 use strict;
 use Moo::Role;
 
@@ -14,7 +14,6 @@ has influences => (
     is => 'ro',
     default => sub { BalanceOfPower::Relations::RelPack->new() },
     handles => { reset_influences => 'delete_link_for_node',
-                 print_influences => 'print_links', 
                  add_influence => 'add_link' }
 );
 sub influences_garbage_collector
@@ -167,4 +166,14 @@ sub situation_clock
     $self->influences_garbage_collector();
 }
 
+sub print_influences
+{
+    my $self = shift;
+    my $n = shift;
+    my $mode = shift || 'print';
+    my @inf = $self->influences->links_for_node($n);
+    return BalanceOfPower::Printer::print($mode, $self, 'print_influences', 
+                                          { influences => \@inf } );
+}
+
 1;
