@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Supporter;
-$BalanceOfPower::Role::Supporter::VERSION = '0.200000';
+$BalanceOfPower::Role::Supporter::VERSION = '0.300000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -21,7 +21,6 @@ has military_supports => (
                  supports => 'links_for_node',
                  supporter => 'links_for_node1',
                  supported => 'first_link_for_node2',
-                 print_military_supports => 'print_links',
                  reset_supports => 'delete_link_for_node'
                }
 );
@@ -34,7 +33,6 @@ has rebel_military_supports => (
                  rebel_supports => 'links_for_node',
                  rebel_supporter => 'links_for_node1',
                  rebel_supported => 'first_link_for_node2',
-                 print_rebel_military_supports => 'print_links',
                  reset_rebel_supports => 'delete_link_for_node'
                }
 );
@@ -141,4 +139,42 @@ sub rebel_military_support_garbage_collector
     $self->rebel_military_supports->garbage_collector(sub { my $rel = shift; return $rel->army <= 0 });
 }
 
+sub print_military_supports
+{
+    my $self = shift;
+    my $n = shift;
+    my $mode = shift || 'print';
+    return $self->print_supports($n, "MILITARY SUPPORTS", 0, $mode);
+}
+sub print_rebel_military_supports
+{
+    my $self = shift;
+    my $n = shift;
+    my $mode = shift || 'print';
+    return $self->print_supports($n, "REBEL MILITARY SUPPORTS", 1, $mode);
+}
+
+
+sub print_supports
+{
+    my $self = shift;
+    my $n = shift;
+    my $title = shift || "MILITARY SUPPORTS";
+    my $rebel = shift;
+    my $mode = shift || 'print';
+    my @sups;
+    if($rebel)
+    {
+        @sups = $self->rebel_military_supports->links_for_node($n);
+    }
+    else
+    {
+        @sups = $self->military_supports->links_for_node($n);
+    }
+    return BalanceOfPower::Printer::print($mode, $self, 'print_supports', 
+                                   {   title => $title,
+                                       supports => \@sups,
+                                   } );
+
+}
 1;
