@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Warlord;
-$BalanceOfPower::Role::Warlord::VERSION = '0.200000';
+$BalanceOfPower::Role::Warlord::VERSION = '0.300000';
 use strict;
 use v5.10;
 
@@ -8,7 +8,7 @@ use Moo::Role;
 use Term::ANSIColor;
 
 use BalanceOfPower::Constants ':all';
-use BalanceOfPower::Utils qw( as_title );
+use BalanceOfPower::Printer;
 use BalanceOfPower::Relations::Crisis;
 use BalanceOfPower::Relations::War;
 
@@ -65,7 +65,10 @@ sub in_military_range
     my $nation1 = shift;
     my $nation2 = shift;
     my $hostile = shift || 1;
-    return 1 if($self->border_exists($nation1, $nation2));
+    if($self->border_exists($nation1, $nation2))
+    {
+        return 1;
+    }
     my @supported = $self->supporter($nation1);
     for(@supported)
     {
@@ -75,8 +78,17 @@ sub in_military_range
         {
             if(! $self->war_busy($nation_supported))
             {
-                return 1 if $nation_supported eq $nation2 ||
-                            $self->border_exists($nation_supported, $nation2);
+                if($nation_supported eq $nation2)
+                {
+                    return 1;
+                }
+                if($self->border_exists($nation_supported, $nation2))
+                {
+                    return 1;
+                }
+            }
+            else
+            {
             }
         }
     }
@@ -543,12 +555,13 @@ sub delete_war
     $self->delete_war_link($nation1, $nation2);
 }
 
+
 sub print_wars
 {
     my $self = shift;
+    my $nation = shift;
+    my $mode = shift || 'print';
     my %grouped_wars;
-    my $out = "";
-    $out .= as_title("WARS\n===\n");
     foreach my $w ($self->wars->all())
     {
         if(! exists $grouped_wars{$w->war_id})
@@ -557,27 +570,38 @@ sub print_wars
         }
         push @{$grouped_wars{$w->war_id}}, $w; 
     }
+    my @wars;
     foreach my $k (keys %grouped_wars)
     {
-        $out .= "### WAR $k\n";
+        my %war;
+        $war{'name'} = $k;
+        $war{'conflicts'} = [];
         foreach my $w ( @{$grouped_wars{$k}})
         {
+            my %subwar;
+            $subwar{'node1'} = $w->node1;
+            $subwar{'node2'} = $w->node2;
             my $nation1 = $self->get_nation($w->node1);
             my $nation2 = $self->get_nation($w->node2);
-            $out .= $w->print($nation1->army, $nation2->army);
-            $out .= "\n";
+            $subwar{'army1'} = $nation1->army;
+            $subwar{'army2'} = $nation2->army;
+            $subwar{'node1_faction'} = $w->node1_faction;
+            $subwar{'node2_faction'} = $w->node2_faction;
+            push @{$war{'conflicts'}}, \%subwar;
         }
-        $out .= "---\n";
+        push @wars, \%war;
     }
-    $out .= "\n";
+    my @civil_wars;
     foreach my $n (@{$self->nation_names})
     {
         if($self->at_civil_war($n))
         {
-            $out .= "$n is fighting civil war\n";
+            push @civil_wars, $n;
         }
     }
-    return $out;
+    return BalanceOfPower::Printer::print($mode, $self, 'print_wars', 
+                                   { wars => \@wars,
+                                     civil_wars => \@civil_wars } );
 }
 sub dump_memorial
 {
