@@ -1,11 +1,12 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.200000';
+$BalanceOfPower::World::VERSION = '0.300000';
 use strict;
 use v5.10;
 
 use Moo;
 use Data::Dumper;
 use Cwd 'abs_path';
+use File::Path 'make_path';
 
 use BalanceOfPower::Constants ':all';
 use BalanceOfPower::Utils qw(prev_turn next_turn);
@@ -93,6 +94,7 @@ with 'BalanceOfPower::Role::Broker';
 with 'BalanceOfPower::Role::Warlord';
 with 'BalanceOfPower::Role::CrisisManager';
 with 'BalanceOfPower::Role::Analyst';
+with 'BalanceOfPower::Role::WebMaster';
 with 'BalanceOfPower::Role::Recorder';
 
 sub get_nation
@@ -225,6 +227,7 @@ sub init_random
             export_quote => $export_quote, 
             government_strength => $government_strength,
             available_stocks => START_STOCKS->[$nations_data{$n}->{size}],
+            log_dir => $self->log_dir,
             log_name => $self->log_name,
             log_on_stdout => $self->log_on_stdout);
         $self->nation_codes->{$nations_data{$n}->{code}} = $n;
@@ -294,6 +297,8 @@ sub elaborate_turn
     $self->post_decisions_elaborations();
 }
 
+
+
 #To automatically generate turns
 sub autopilot
 {
@@ -712,7 +717,6 @@ sub control
         my $player_command = $player->get_control_order($nation);
         if($player_command)
         {
-            $player->add_influence(-1 * INFLUENCE_COST, $nation);
             if($player->stocks($nation) > $quote)
             {
                 if($winner)
@@ -731,6 +735,7 @@ sub control
     }
     if($winner)
     {
+        $winner->add_influence(-1 * INFLUENCE_COST, $nation);
         $winner->register_event("ORDER FOR $nation IS EXECUTED: $winner_command");
         for(@losers)
         {
@@ -996,8 +1001,29 @@ sub collect_events
 sub build_commands
 {
     my $self = shift;
-    my $commands = BalanceOfPower::Commands->new( world => $self, log_name => 'bop-commands.log', log_active => $self->log_active );
+    my $commands = BalanceOfPower::Commands->new( world => $self, log_name => 'bop-commands.log', log_active => $self->log_active, log_dir => $self->log_dir );
     return $commands;
 }
 
+### Logs
+
+sub set_log_dir
+{
+    my $self = shift;
+    my $log_dir = shift;
+
+    $self->log_dir($log_dir);
+    $self->dice->log_dir($log_dir);
+
+    for(@{$self->nations})
+    {
+        $_->log_dir($log_dir);
+    }
+    for(@{$self->players})
+    {
+        $_->log_dir($log_dir);
+    }
+}
+
+
 1;
